import {demoConfig} from "./demo-config";
import "@vanillawc/wc-codemirror";

import "./script-graph";
import "./script-graph2";

import { mdiAsterisk, mdiArrowUp, mdiArrowDown } from "@mdi/js";

let index_counter = 0;
let nodes = [];

const structure_tree = (inp) => {
  if(!inp) return null;
  if(Array.isArray(inp)) return inp.map(structure_tree);
  let data = {};
  let type = "YAML";
  
  const idx = index_counter++;
  if("service" in inp) type = "service";
  if("condition" in inp) type = "condition";
  if("delay" in inp) type = "delay";
  if("wait_template" in inp) type = "wait";
  if("event" in inp) type = "event";
  if("repeat" in inp) {
    type = "loop";
    data = {sequence: structure_tree(inp.repeat.sequence)};
  }
  if("choose" in inp) {
    type = "choose";
    let choices = [];
    for (const [i,c] of inp.choose.entries()) {
      const header = {
        type: "chooseChoice",
        idx: [idx, i],
      }
      choices.push([header].concat(structure_tree(c.sequence)));
    }
    choices.push([{
      type: "chooseDefault",
      idx: [idx, -1],
    }].concat(structure_tree(inp.default)));
    data = {
      choices,
    }
  }
  nodes[idx] = inp;
  return {type,
    idx,
    ...data};

}

const structure_tree2 = () => {
  return [
    {
      icon: mdiAsterisk,
      clickCallback: () => console.log("Number 1"),
    },
    {
      icon: mdiAsterisk,
      clickCallback: () => console.log("Number 2"),
    },
    {
      icon: mdiAsterisk,
      clickCallback: () => console.log("Number 3"),
    },
    {
      icon: mdiAsterisk,
      clickCallback: () => console.log("Number 4"),
      children: [
        [
          {
            icon: mdiAsterisk,
            clickCallback: () => console.log("Number A1"),
          },
          {
            icon: mdiAsterisk,
            clickCallback: () => console.log("Number A2"),
          },
        ],
        {
          icon: mdiAsterisk,
          clickCallback: () => console.log("Number B"),
          end: false,
        },
        {
          icon: mdiAsterisk,
          clickCallback: () => console.log("Number B"),
        },
        {
          icon: mdiAsterisk,
          clickCallback: () => console.log("Number B"),
        },
      ]
    },
    {
      icon: mdiAsterisk,
      clickCallback: () => console.log("Number 4"),
      children: [
          {
            icon: mdiArrowUp,
            clickCallback: () => console.log("Return"),
          },
          {
            icon: mdiArrowDown,
            clickCallback: () => console.log("Return"),
          },
        ],
    },
    {
      icon: mdiAsterisk,
      clickCallback: () => console.log("Number 1"),
    },
  ];
}

window.onload = () => {

  let src = demoConfig;

  const fullcode = document.querySelector("wc-codemirror");
  fullcode.mode = "yaml";
  window.setTimeout(()=> fullcode.value = jsyaml.safeDump(src), 100);

  const updateButton = document.querySelector("#updateButton");
  updateButton.addEventListener('click', () => {
    src = jsyaml.safeLoad(fullcode.value);
    index_counter = 0;
    nodes = [];
    graph.tree = structure_tree(src);
  });

  const graph = document.createElement("script-graph");
  graph.tree = structure_tree(src);

  const graph2 = document.createElement("script-graph2");
  graph2.tree = structure_tree2(src);
  document.querySelector("#graph2").appendChild(graph2);

  graph.addEventListener("selected", (ev) => {
    const idx = ev.detail;
    const code = document.querySelector("code");
    let c;
    if(Array.isArray(idx)) {
      c = nodes[idx[0]].choose[idx[1]];
    } else {
      c = nodes[idx];
    }
    code.innerHTML = JSON.stringify(c, null, '  ');

  })
  document.querySelector("#graph").appendChild(graph);


}
